#!/usr/bin/env python
# coding=utf-8
import os, sys
import glob # For filename search with wildcards
import numpy as np
import sapatt as sp # scattering pattern
import sapiawin as sw # presentation windows

'''lastcurve.py: Helper script for the extraction of a single curve from the
   last pattern which has been opened for display by @@pattshow in "portrait"
   orientation, if the user has identified the curve by pointing at it by
   "l"ine input. The horizontal line which is identified by the end point of
   the vector is used. The vector coordinates are in self.lastline.

   If <myframe> is given, this frame is extracted instead of the frame
   identified by self.lastline

SYNTAX:  @@lastcurve,<opi>[1],<myframe>['']
         The curve is read into <opi> of saskia
         <opi>: 0, 1 or 2
Examples: @@pattshow,nmbwy06tot # Load (WAXS) pattern in portrait mode
          @@lastcurve,1,364     # Extract frame 364 to OP1

'''


## Script procedures
def argexpand( specs ):
    '''Expand the argument list, if the user has given less than specs
    arguments'''
    result = sys.argv[1:]
    while len( result ) < specs:
        result.append( '' )
    return result
#END argexpand()

def banner():
    # print the name of the running script
    myname = os.path.basename(sys.argv[0])
    #self.poutput("Finished: {!r}".format(myname))
    self.poutput("Finished: {!r}".format(sys.argv[0])) # complete
    pass
#END banner()

def doit():
    '''doit does the work'''
    #argument lister
    #for i, arg in enumerate(sys.argv[1:]):
    #    print("arg {}: {!r}".format(i+1, arg))

    argus = len( sys.argv ) - 1 # Number of provided arguments

    if self.patt is None:
        return 'No last pattern available in self.patt'

    if argus < 2:
        if self.patt.lastline is None:
            return 'No curve identified by pointing with "l"ine'

    ### Argument parsing
    arglist = argexpand( 2 )

    ## (1) The operand array which shall be filled by the curve
    opis = arglist[0]
    if opis == '':
        opis = '1'
    try:
        opi = int(opis)
    except:
        return 'Error converting opi "%s"'%opis
    opi = abs(opi)
    if opi > 2:
        return 'opi must be smaller than 3 "%s"'%opis

    if argus < 2:
        index = int(self.patt.lastline[3] + 0.5) # y2 in portrait representation
    else:
        try:
            index = int(arglist[1])
        except:
            return 'Error converting myframe "%s"'%arglist[1]
        index = abs(index)
        if index > self.patt.height-1:
            return 'myframe is bigger than the number of curves contained in the pattern'
    thecurve = self.ops[opi]
    thecurve.clean()
    # Generate basic curve data
    span = self.patt.width
    thecurve.y[:span] = self.patt.mapp[index,:]
    thecurve.x[:span] = self.patt.geta('s')
    thecurve.n = span
    # Make a file name for storing the extracted curve
    indexs = str(index)
    while len(indexs) < 4:
        indexs = '0'+indexs
    pattfn = self.patt.geta('fn')
    thecurve.lastfile = pattfn+'_'+indexs+'_x.dat'
    # Generate attributes
    temperatures = self.patt.geta('T')
    temp = temperatures[index]
    thecurve.puta('T',temp)
    times = self.patt.geta('elapsed')
    thecurve.puta('elapsed',times[index])
    thecurve.puta('frame',index)

    # common extra attributes
    thecurve.puta('axis1','$s$')
    thecurve.puta('units1','nm$^{{-1}}$')
    if pattfn.find('tot'):
        thecurve.puta('axis2','$s^2 I(s)/V$')
        thecurve.puta('units2','e.u.nm$^{{-5}}$')
    else:
        thecurve.puta('axis2','$I(s)/V$')
        thecurve.puta('units2','e.u.nm$^{{-3}}$')
    print('Extracted curve now in OP%i'%opi)
#END doit()

# END script procedures

# ****************** Main *******************************************
# Make a window dictionary, if it does not exist
try:
    self.piawinds
except:
    self.piawinds = {}
self.pia = sw.piawins( self.piawinds )
err = doit()
if err:
    self.poutput( 'ERROR: '+err )
    # No signaling of error to the caller
banner()
